@@ -101,6 +101,7 @@ TO_REMOVE_FOLDER = "_to_rm"
 # Tentacles folders
 TENTACLES_PATH = "tentacles"
 DEFAULT_BOT_PATH = CURRENT_DIR_PATH
+TENTACLES_AUTOMATION_PATH = "Automation"
 TENTACLES_BACKTESTING_PATH = "Backtesting"
 TENTACLES_EVALUATOR_PATH = "Evaluator"
 TENTACLES_META_PATH = "Meta"
@@ -114,6 +115,9 @@ TENTACLES_TRADING_PATH = "Trading"
 
 # Tentacles sub-folders
 TENTACLE_MAX_SUB_FOLDERS_LEVEL = 3
+TENTACLES_AUTOMATION_TRIGGER_EVENTS_PATH = "trigger_events"
+TENTACLES_AUTOMATION_CONDITIONS_PATH = "conditions"
+TENTACLES_AUTOMATION_ACTIONS_PATH = "actions"
 TENTACLES_BACKTESTING_COLLECTORS_PATH = "collectors"
 TENTACLES_BACKTESTING_CONVERTERS_PATH = "converters"
 TENTACLES_BACKTESTING_IMPORTERS_PATH = "importers"
@@ -160,6 +164,11 @@ SETUP_FILE = "setup.py"
 
 # Tentacles architecture
 TENTACLES_FOLDERS_ARCH = {
+    TENTACLES_AUTOMATION_PATH: [
+        TENTACLES_AUTOMATION_TRIGGER_EVENTS_PATH,
+        TENTACLES_AUTOMATION_CONDITIONS_PATH,
+        TENTACLES_AUTOMATION_ACTIONS_PATH,
+    ],
     TENTACLES_BACKTESTING_PATH: {
         TENTACLES_BACKTESTING_COLLECTORS_PATH: [
             TENTACLES_BACKTESTING_THIRD_LEVEL_EXCHANGES_PATH,
