@@ -22,8 +22,11 @@ from octobot_tentacles_manager.loaders.tentacle_loading import (
     ensure_tentacles_metadata,
     get_resources_path,
     get_tentacle_module_path,
+    get_tentacles_classes_names_from_tentacle_module,
     get_documentation_file_path,
     get_tentacle,
+    get_tentacle_class_from_name,
+    set_tentacle_class_by_name,
 )
 
 __all__ = [
@@ -32,6 +35,9 @@ __all__ = [
     "ensure_tentacles_metadata",
     "get_resources_path",
     "get_tentacle_module_path",
+    "get_tentacles_classes_names_from_tentacle_module",
     "get_documentation_file_path",
     "get_tentacle",
+    "get_tentacle_class_from_name",
+    "set_tentacle_class_by_name",
 ]
